Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrUnsupportedKind ¶
type ErrUnsupportedKind struct {
// contains filtered or unexported fields
}
ErrUnsupportedKind is the error that is returned if the yaml.Node's kind is not supported.
func (ErrUnsupportedKind) Error ¶
func (err ErrUnsupportedKind) Error() string
Error implements the error interface.
type SliceOrObject ¶
type SliceOrObject[T any] []T
SliceOrObject represents a slice that can also be represented by a single object for a single-item slice.
func (*SliceOrObject[T]) UnmarshalYAML ¶
func (soo *SliceOrObject[T]) UnmarshalYAML(value *yaml.Node) error
UnmarshalYAML implements the yaml.Unmarshaler interface.
Click to show internal directories.
Click to hide internal directories.